<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Ziegler Gábor <gziegler@freemail.hu>
 * @author Sandor TIHANYI <stihanyi+dw@gmail.com>
 * @author Siaynoq Mage <siaynoqmage@gmail.com>
 * @author schilling.janos@gmail.com
 * @author Szabó Dávid <szabo.david@gyumolcstarhely.hu>
 * @author Sándor TIHANYI <stihanyi+dw@gmail.com>
 * @author David Szabo <szabo.david@gyumolcstarhely.hu>
 * @author Marton Sebok <sebokmarton@gmail.com>
 * @author Serenity87HUN <anikototh87@gmail.com>
 * @author Marina Vladi <deldadam@gmail.com>
 * @author Mátyás Jani <jzombi@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Oldal szerkesztése';
$lang['btn_source']            = 'Oldalforrás megtekintése';
$lang['btn_show']              = 'Oldal megtekintése';
$lang['btn_create']            = 'Oldal létrehozása';
$lang['btn_search']            = 'Keresés';
$lang['btn_save']              = 'Mentés';
$lang['btn_preview']           = 'Előnézet';
$lang['btn_top']               = 'Vissza a tetejére';
$lang['btn_newer']             = '<< Újabb változat';
$lang['btn_older']             = 'Régebbi változat >>';
$lang['btn_revs']              = 'Korábbi változatok';
$lang['btn_recent']            = 'Legfrissebb változások';
$lang['btn_upload']            = 'Feltöltés';
$lang['btn_cancel']            = 'Mégsem';
$lang['btn_index']             = 'Áttekintő';
$lang['btn_secedit']           = 'Szerkesztés';
$lang['btn_login']             = 'Bejelentkezés';
$lang['btn_logout']            = 'Kijelentkezés';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Frissítés';
$lang['btn_delete']            = 'Törlés';
$lang['btn_back']              = 'Vissza';
$lang['btn_backlink']          = 'Hivatkozások';
$lang['btn_subscribe']         = 'Feliratkozás az oldalváltozásokra';
$lang['btn_profile']           = 'Személyes beállítások';
$lang['btn_reset']             = 'Alaphelyzet';
$lang['btn_resendpwd']         = 'Jelszóváltoztatás';
$lang['btn_draft']             = 'Piszkozat szerkesztése';
$lang['btn_recover']           = 'Piszkozat folytatása';
$lang['btn_draftdel']          = 'Piszkozat törlése';
$lang['btn_revert']            = 'Helyreállítás';
$lang['btn_register']          = 'Regisztráció';
$lang['btn_apply']             = 'Alkalmaz';
$lang['btn_media']             = 'Médiakezelő';
$lang['btn_deleteuser']        = 'Felhasználói fiókom eltávolítása';
$lang['btn_img_backto']        = 'Vissza %s';
$lang['btn_mediaManager']      = 'Megtekintés a médiakezelőben';
$lang['loggedinas']            = 'Belépett felhasználó';
$lang['user']                  = 'Azonosító';
$lang['pass']                  = 'Jelszó';
$lang['newpass']               = 'Új jelszó';
$lang['oldpass']               = 'Régi jelszó';
$lang['passchk']               = 'még egyszer';
$lang['remember']              = 'Emlékezz rám';
$lang['fullname']              = 'Teljes név';
$lang['email']                 = 'E-Mail';
$lang['profile']               = 'Személyes beállítások';
$lang['badlogin']              = 'Sajnáljuk, az azonosító vagy a jelszó nem jó.';
$lang['badpassconfirm']        = 'Hibás jelszó';
$lang['minoredit']             = 'Apróbb változások';
$lang['draftdate']             = 'Piszkozat elmentve:';
$lang['nosecedit']             = 'Időközben megváltozott az oldal, emiatt a szakasz nem friss. Töltsd újra az egész oldalt!';
$lang['regmissing']            = 'Sajnáljuk, az összes mezőt ki kell töltened.';
$lang['reguexists']            = 'Sajnáljuk, ilyen azonosítójú felhasználónk már van.';
$lang['regsuccess']            = 'A felhasználói azonosítót létrehoztuk. A jelszót postáztuk.';
$lang['regsuccess2']           = 'A felhasználói azonosítót létrehoztuk.';
$lang['regfail']               = 'A felhasználó létrehozása sikertelen.';
$lang['regmailfail']           = 'Úgy tűnik hiba történt a jelszó postázása során. Kérjük lépj kapcsolatba az Adminisztrátorokkal!';
$lang['regbadmail']            = 'A megadott e-mail cím érvénytelennek tűnik. Ha úgy gondolod ez hiba, lépj kapcsolatba az Adminisztrátorokkal!';
$lang['regbadpass']            = 'A két megadott jelszó nem egyezik, próbáld újra!';
$lang['regpwmail']             = 'A DokuWiki jelszavad';
$lang['reghere']               = 'Még nincs azonosítód? Itt kérhetsz';
$lang['profna']                = 'Ez a wiki nem támogatja a személyes beállítások módosítását.';
$lang['profnochange']          = 'Nem történt változás.';
$lang['profnoempty']           = 'A név és e-mail mező nem maradhat üresen!';
$lang['profchanged']           = 'A személyes beállítások változtatása megtörtént.';
$lang['profnodelete']          = 'Ez a wiki nem támogatja a felhasználói fiókok törlését';
$lang['profdeleteuser']        = 'Felhasználói fiók törlése';
$lang['profdeleted']           = 'Felhasználói fiókodat eltávolítottuk erről a wiki-ről.';
$lang['profconfdelete']        = 'Szeretném eltávolítani a felhasználói fiókomat erről a wikiről. <br/> Ez a cselekvés nem visszavonható.';
$lang['profconfdeletemissing'] = 'A megerősítő négyzet nincs bepipálva';
$lang['proffail']              = 'A profil frissítése sikertelen.';
$lang['pwdforget']             = 'Elfelejtetted a jelszavad? Itt kérhetsz újat';
$lang['resendna']              = 'Ez a wiki nem támogatja a jelszó újraküldést.';
$lang['resendpwd']             = 'Új jelszó beállítása a következőhöz:';
$lang['resendpwdmissing']      = 'Sajnáljuk, az összes mezőt ki kell töltened.';
$lang['resendpwdnouser']       = 'Sajnáljuk, ilyen azonosítójú felhasználónk nem létezik.';
$lang['resendpwdbadauth']      = 'Sajnáljuk, ez a megerősítő kód nem helyes. Biztos, hogy a teljes megerősítő linket pontosan beírtad?';
$lang['resendpwdconfirm']      = 'A megerősítő linket e-mailben elküldtük.';
$lang['resendpwdsuccess']      = 'Az új jelszavadat elküldtük e-mailben.';
$lang['license']               = 'Hacsak máshol nincs egyéb rendelkezés, ezen wiki tartalma a következő licenc alatt érhető el:';
$lang['licenseok']             = 'Megjegyzés: az oldal szerkesztésével elfogadja, hogy a tartalom a következő licenc alatt lesz elérhető:';
$lang['searchmedia']           = 'Keresett fájl neve:';
$lang['searchmedia_in']        = 'Keresés a következőben: %s';
$lang['txt_upload']            = 'Válaszd ki a feltöltendő fájlt:';
$lang['txt_filename']          = 'Feltöltési név (elhagyható):';
$lang['txt_overwrt']           = 'Létező fájl felülírása';
$lang['maxuploadsize']         = 'Maximum %s méretű fájlokat tölthetsz fel.';
$lang['lockedby']              = 'Jelenleg zárolta:';
$lang['lockexpire']            = 'A zárolás lejár:';
$lang['js']['willexpire']      = 'Az oldalszerkesztési zárolásod körülbelül egy percen belül lejár.\nAz ütközések elkerülése végett használd az előnézet gombot a zárolásod frissítéséhez.';
$lang['js']['notsavedyet']     = 'Elmentetlen változások vannak, amelyek el fognak veszni.
Tényleg ezt akarod?';
$lang['js']['searchmedia']     = 'Fájlok keresése';
$lang['js']['keepopen']        = 'Tartsd nyitva ezt az ablakot a kijelöléshez!';
$lang['js']['hidedetails']     = 'Részletek elrejtése';
$lang['js']['mediatitle']      = 'Link beállítások';
$lang['js']['mediadisplay']    = 'Link típusa';
$lang['js']['mediaalign']      = 'Igazítás';
$lang['js']['mediasize']       = 'Képméret';
$lang['js']['mediatarget']     = 'Link célja';
$lang['js']['mediaclose']      = 'Bezárás';
$lang['js']['mediainsert']     = 'Beillesztés';
$lang['js']['mediadisplayimg'] = 'Kép megtekintése.';
$lang['js']['mediadisplaylnk'] = 'Link megtekintése.';
$lang['js']['mediasmall']      = 'Kis méret';
$lang['js']['mediamedium']     = 'Közepes méret';
$lang['js']['medialarge']      = 'Nagy méret';
$lang['js']['mediaoriginal']   = 'Eredeti verzió';
$lang['js']['medialnk']        = 'Link a részletekre';
$lang['js']['mediadirect']     = 'Közvetlen link az eredetire';
$lang['js']['medianolnk']      = 'Nincs link';
$lang['js']['medianolink']     = 'Ne linkelje a képet';
$lang['js']['medialeft']       = 'Kép igazítása balra.';
$lang['js']['mediaright']      = 'Kép igazítása jobbra.';
$lang['js']['mediacenter']     = 'Kép igazítása középre.';
$lang['js']['medianoalign']    = 'Nem legyen igazítás.';
$lang['js']['nosmblinks']      = 'A Windows megosztott könyvtárak kereszthivatkozása csak Microsoft Internet Explorerben működik közvetlenül.\nA hivatkozást másolni és beszúrni ettől függetlenül mindig tudod.';
$lang['js']['linkwiz']         = 'Hivatkozás varázsló';
$lang['js']['linkto']          = 'Hivatkozás erre:';
$lang['js']['del_confirm']     = 'Valóban törölni akarod a kiválasztott elem(ek)et?';
$lang['js']['restore_confirm'] = 'Valóban visszaállítod ezt a verziót?';
$lang['js']['media_diff']      = 'Különbségek megtekintése:';
$lang['js']['media_diff_both'] = 'Egymás mellett';
$lang['js']['media_diff_opacity'] = 'Áttetszően';
$lang['js']['media_diff_portions'] = 'Húzással';
$lang['js']['media_select']    = 'Fájlok kiválasztása...';
$lang['js']['media_upload_btn'] = 'Feltöltés';
$lang['js']['media_done_btn']  = 'Kész';
$lang['js']['media_drop']      = 'Húzd ide a fájlokat a feltöltéshez';
$lang['js']['media_cancel']    = 'eltávolítás';
$lang['js']['media_overwrt']   = 'Meglévő fájlok felülírása';
$lang['rssfailed']             = 'Hiba történt a hírfolyam betöltésekor: ';
$lang['nothingfound']          = 'Üres mappa.';
$lang['mediaselect']           = 'Médiafájl kiválasztása';
$lang['uploadsucc']            = 'Sikeres feltöltés';
$lang['uploadfail']            = 'A feltöltés nem sikerült. Talán rosszak a jogosultságok?';
$lang['uploadwrong']           = 'A feltöltés megtagadva. Ez a fájlkiterjesztés tiltott.';
$lang['uploadexist']           = 'A fájl már létezik, nem történt semmi.';
$lang['uploadbadcontent']      = 'A feltöltött tartalom nem egyezik a %s fájlkiterjesztéssel.';
$lang['uploadspam']            = 'A feltöltést visszautasítottuk spam-gyanú miatt.';
$lang['uploadxss']             = 'A feltöltést visszautasítottuk, mert lehetséges, hogy kártékony kódot tartalmaz.';
$lang['uploadsize']            = 'A feltöltött fájl túl nagy. (max. %s)';
$lang['deletesucc']            = 'A "%s" fájlt töröltük.';
$lang['deletefail']            = 'A "%s" fájl nem törölhető - ellenőrizd a jogosultságokat!';
$lang['mediainuse']            = 'A "%s" fájl nem törlődött - még használat alatt van!';
$lang['namespaces']            = 'Névterek';
$lang['mediafiles']            = 'Elérhető fájlok itt:';
$lang['accessdenied']          = 'Nincs jogod az oldal megtekintésére.';
$lang['mediausage']            = 'A következő formában hivatkozhatsz erre a fájlra:';
$lang['mediaview']             = 'Eredeti fájl megtekintése';
$lang['mediaroot']             = 'kiindulási hely';
$lang['mediaupload']           = 'Itt tölthetsz fel állományt az aktuális névtérbe. Alnévtér létrehozásához a "Feltöltési név" mezőben kell kettősponttal elválasztva megadnod azt.';
$lang['mediaextchange']        = 'Az állomány kiterjesztése erről: .%s erre: .%s változott!';
$lang['reference']             = 'Hivatkozások';
$lang['ref_inuse']             = 'A fájl nem törölhető, mert a következő oldalakon használják:';
$lang['ref_hidden']            = 'Van néhány hivatkozás az oldalakon, amelyekhez nincs olvasási jogosultságod';
$lang['hits']                  = 'Találatok';
$lang['quickhits']             = 'Illeszkedő oldalnevek';
$lang['toc']                   = 'Tartalomjegyzék';
$lang['current']               = 'aktuális';
$lang['yours']                 = 'A Te változatod';
$lang['diff']                  = 'Különbségek az aktuális változathoz képest';
$lang['diff2']                 = 'Különbségek a kiválasztott változatok között';
$lang['difflink']              = 'Összehasonlító nézet linkje';
$lang['diff_type']             = 'Összehasonlítás módja:';
$lang['diff_inline']           = 'Sorok között';
$lang['diff_side']             = 'Egymás mellett';
$lang['diffprevrev']           = 'Előző változat';
$lang['diffnextrev']           = 'Következő változat';
$lang['difflastrev']           = 'Utolsó változat';
$lang['diffbothprevrev']       = 'Előző változat mindkét oldalon';
$lang['diffbothnextrev']       = 'Következő változat mindkét oldalon';
$lang['line']                  = 'Sor';
$lang['breadcrumb']            = 'Nyomvonal:';
$lang['youarehere']            = 'Itt vagy:';
$lang['lastmod']               = 'Utolsó módosítás:';
$lang['by']                    = 'szerkesztette:';
$lang['deleted']               = 'eltávolítva';
$lang['created']               = 'létrehozva';
$lang['restored']              = 'régebbi változat helyreállítva (%s)';
$lang['external_edit']         = 'külső szerkesztés';
$lang['summary']               = 'A változások összefoglalása';
$lang['noflash']               = 'Ennek a tartalomnak a megtekintéséhez <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> szükséges.';
$lang['download']              = 'Kódrészlet letöltése';
$lang['tools']                 = 'Eszközök';
$lang['user_tools']            = 'Felhasználói eszközök';
$lang['site_tools']            = 'Eszközök a webhelyen';
$lang['page_tools']            = 'Eszközök az oldalon';
$lang['skip_to_content']       = 'ugrás a tartalomhoz';
$lang['sidebar']               = 'Oldalsáv';
$lang['mail_newpage']          = 'új oldal jött létre:';
$lang['mail_changed']          = 'oldal megváltozott:';
$lang['mail_subscribe_list']   = 'oldalak megváltoztak ebben a névtérben:';
$lang['mail_new_user']         = 'új felhasználó:';
$lang['mail_upload']           = 'új állományt töltöttek fel:';
$lang['changes_type']          = 'A következő változásainak megtekintése:';
$lang['pages_changes']         = 'Oldalak';
$lang['media_changes']         = 'Médiafájlok';
$lang['both_changes']          = 'Oldalak és médiafájlok';
$lang['qb_bold']               = 'Félkövér szöveg';
$lang['qb_italic']             = 'Dőlt szöveg';
$lang['qb_underl']             = 'Aláhúzott szöveg';
$lang['qb_code']               = 'Forráskód';
$lang['qb_strike']             = 'Áthúzott szöveg';
$lang['qb_h1']                 = '1. szintű címsor';
$lang['qb_h2']                 = '2. szintű címsor';
$lang['qb_h3']                 = '3. szintű címsor';
$lang['qb_h4']                 = '4. szintű címsor';
$lang['qb_h5']                 = '5. szintű címsor';
$lang['qb_h']                  = 'Címsor';
$lang['qb_hs']                 = 'Címsor kiválasztása';
$lang['qb_hplus']              = 'Nagyobb címsor';
$lang['qb_hminus']             = 'Kisebb címsor';
$lang['qb_hequal']             = 'Azonos szintű címsor';
$lang['qb_link']               = 'Belső hivatkozás';
$lang['qb_extlink']            = 'Külső hivatkozás';
$lang['qb_hr']                 = 'Vízszintes elválasztó vonal';
$lang['qb_ol']                 = 'Sorszámozott lista elem';
$lang['qb_ul']                 = 'Felsorolásos lista elem';
$lang['qb_media']              = 'Képek és más fájlok hozzáadása';
$lang['qb_sig']                = 'Aláírás beszúrása';
$lang['qb_smileys']            = 'Smiley-k';
$lang['qb_chars']              = 'Speciális karakterek';
$lang['upperns']               = 'ugrás a tartalmazó névtérhez';
$lang['metaedit']              = 'Metaadatok szerkesztése';
$lang['metasaveerr']           = 'A metaadatok írása nem sikerült';
$lang['metasaveok']            = 'Metaadatok elmentve';
$lang['img_title']             = 'Cím:';
$lang['img_caption']           = 'Képaláírás:';
$lang['img_date']              = 'Dátum:';
$lang['img_fname']             = 'Fájlnév:';
$lang['img_fsize']             = 'Méret:';
$lang['img_artist']            = 'Készítette:';
$lang['img_copyr']             = 'Szerzői jogok:';
$lang['img_format']            = 'Formátum:';
$lang['img_camera']            = 'Fényképezőgép típusa:';
$lang['img_keywords']          = 'Kulcsszavak:';
$lang['img_width']             = 'Szélesség:';
$lang['img_height']            = 'Magasság:';
$lang['subscr_subscribe_success'] = '%s hozzáadva az értesítési listához: %s';
$lang['subscr_subscribe_error'] = 'Hiba történt %s hozzáadásakor az értesítési listához: %s';
$lang['subscr_subscribe_noaddress'] = 'Nincs e-mail cím megadva az adataidnál, így a rendszer nem tudott hozzáadni az értesítési listához';
$lang['subscr_unsubscribe_success'] = '%s eltávolítva az értesítési listából: %s';
$lang['subscr_unsubscribe_error'] = 'Hiba történt %s eltávolításakor az értesítési listából: %s';
$lang['subscr_already_subscribed'] = '%s már feliratkozott erre: %s';
$lang['subscr_not_subscribed'] = '%s nincs feliratkozva erre: %s';
$lang['subscr_m_not_subscribed'] = 'Jelenleg nem vagy feliratkozva erre az oldalra vagy névtérre';
$lang['subscr_m_new_header']   = 'Feliratkozás hozzáadása';
$lang['subscr_m_current_header'] = 'Feliratkozások';
$lang['subscr_m_unsubscribe']  = 'Leiratkozás';
$lang['subscr_m_subscribe']    = 'Feliratkozás';
$lang['subscr_m_receive']      = 'Küldj';
$lang['subscr_style_every']    = 'e-mailt minden változásról';
$lang['subscr_style_digest']   = 'összefoglaló e-mailt oldalanként (minden %.2f nap)';
$lang['subscr_style_list']     = 'egy listát a módosított oldalakról a legutóbbi e-mail óta (minden %.2f nap)';
$lang['authtempfail']          = 'A felhasználó azonosítás átmenetileg nem működik. Ha sokáig így lenne, légy szíves értesítsd az Adminisztrátorokat!';
$lang['i_chooselang']          = 'Válassz nyelvet';
$lang['i_installer']           = 'DokuWiki Beállító Varázsló';
$lang['i_wikiname']            = 'A Wiki neve';
$lang['i_enableacl']           = 'Hozzáférési listák engedélyezése (ajánlott)';
$lang['i_superuser']           = 'Adminisztrátor';
$lang['i_problems']            = 'A Beállító Varázsló a következő problémák miatt megakadt. Nem tudjuk folytatni, amíg ezek nincsenek elhárítva!';
$lang['i_modified']            = 'Biztonsági okokból ez a Varázsló csak új és módosítatlan DokuWiki változaton működik.
Csomagold ki újra a fájlokat a letöltött csomagból, vagy nézd meg a teljes <a href="http://dokuwiki.org/install">Dokuwiki telepítési útmutatót</a>.';
$lang['i_funcna']              = 'A <code>%s</code> PHP funkció nem elérhető. Esetleg a tárhelyszolgáltató letiltotta biztonsági okok miatt?';
$lang['i_phpver']              = 'A PHP <code>%s</code> verziója alacsonyabb, mint ami szükséges lenne: <code>%s</code>. Frissítsd a PHP-det újabb verzióra!';
$lang['i_mbfuncoverload']      = 'A DokuWiki futtatásához az mbstring.func_overload opciót ki kell kapcsolni a php.ini-ben.';
$lang['i_permfail']            = 'A DokiWiki nem tudja írni a <code>%s</code> könyvtárat. Be kell állítanod ehhez a könyvtárhoz a megfelelő jogosultságokat!';
$lang['i_confexists']          = '<code>%s</code> már létezik.';
$lang['i_writeerr']            = 'Nem tudom ezt létrehozni: <code>%s</code>. Ellenőrizd a könyvtár/fájl jogosultságokat, és hozd létre az állományt kézzel.';
$lang['i_badhash']             = 'A dokuwiki.php nem felismerhető vagy módosított (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - nem helyes vagy üres érték';
$lang['i_success']             = 'A beállítás sikeresen befejeződött. Most már letörölhető az install.php fájl. Látogasd meg az <a href="doku.php?id=wiki:welcome">új DokuWikidet</a>!';
$lang['i_failure']             = 'Hiba lépett fel a konfigurációs állományok írásakor. Ki kell javítanod kézzel, mielőtt használni kezded az <a href="doku.php?id=wiki:welcome">új DokuWikidet</a>.';
$lang['i_policy']              = 'Kezdeti hozzáférési lista házirend';
$lang['i_pol0']                = 'Nyitott wiki (mindenki olvashatja, írhatja és fájlokat tölthet fel)';
$lang['i_pol1']                = 'Publikus wiki (mindenki olvashatja, de csak regisztrált felhasználók írhatják és tölthetnek fel fájlokat)';
$lang['i_pol2']                = 'Zárt wiki (csak regisztrált felhasználók olvashatják, írhatják és tölthetnek fel fájlokat)';
$lang['i_allowreg']            = 'A felhasználók saját maguk is regisztrálhatnak';
$lang['i_retry']               = 'Újra';
$lang['i_license']             = 'Kérlek, válassz licencet a feltöltött tartalomhoz:';
$lang['i_license_none']        = 'Ne jelenítsen meg licenc információt';
$lang['i_pop_field']           = 'Kérjük, segíts a DokuWiki továbbfejlesztésében:';
$lang['i_pop_label']           = 'Havonta egyszer névtelen üzenet küldése a DokuWiki fejlesztőinek';
$lang['recent_global']         = 'Jelenleg csak a <b>%s</b> névtér friss változásai látszanak. Megtekinthetők <a href="%s">a teljes wiki friss változásai</a> is.';
$lang['years']                 = '%d évvel ezelőtt';
$lang['months']                = '%d hónappal ezelőtt';
$lang['weeks']                 = '%d héttel ezelőtt';
$lang['days']                  = '%d nappal ezelőtt';
$lang['hours']                 = '%d órával ezelőtt';
$lang['minutes']               = '%d perccel ezelőtt';
$lang['seconds']               = '%d másodperccel ezelőtt';
$lang['wordblock']             = 'A változásokat nem sikerült menteni, mert tiltott tartalom van benne (spam).';
$lang['media_uploadtab']       = 'Feltöltés';
$lang['media_searchtab']       = 'Keresés';
$lang['media_file']            = 'Fájl';
$lang['media_viewtab']         = 'Megtekintés';
$lang['media_edittab']         = 'Szerkesztés';
$lang['media_historytab']      = 'Korábbi változatok';
$lang['media_list_thumbs']     = 'Bélyegképek';
$lang['media_list_rows']       = 'Sorok';
$lang['media_sort_name']       = 'Név';
$lang['media_sort_date']       = 'Dátum';
$lang['media_namespaces']      = 'Névtér kiválasztása';
$lang['media_files']           = 'Fájlok itt: %s';
$lang['media_upload']          = 'Feltöltés ide: %s';
$lang['media_search']          = 'Keresés itt: %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s itt: %s';
$lang['media_edit']            = '%s szerkesztése';
$lang['media_history']         = '%s korábbi változatai';
$lang['media_meta_edited']     = 'metaadatot szerkesztve';
$lang['media_perm_read']       = 'Sajnáljuk, nincs jogod a fájlok olvasásához.';
$lang['media_perm_upload']     = 'Sajnáljuk, nincs jogod a feltöltéshez.';
$lang['media_update']          = 'Új verzió feltöltése';
$lang['media_restore']         = 'Ezen verzió visszaállítása';
$lang['media_acl_warning']     = 'Ez a lista hiányos lehet a hozzáférési listák (ACL) korlátozásai és a rejtett oldalak miatt.';
$lang['currentns']             = 'Aktuális névtér';
$lang['searchresult']          = 'Keresés eredménye';
$lang['plainhtml']             = 'Sima HTML';
$lang['wikimarkup']            = 'Wiki-jelölőnyelv';
$lang['email_signature_text']       = 'Ezt a levelet a DokuWiki generálta
@DOKUWIKIURL@';
$lang['page_nonexist_rev']     = 'A(z) %s oldal nem létezik. Később lett létrehozva a(z) <a href="%s">%s</a> helyen.';
$lang['unable_to_parse_date']  = 'A "%s" paraméter feldolgozása sikertelen.';
